@@ -309,7 +309,7 @@ gdk_pixbuf__xbm_image_load_real (FILE *f, XBMData *context, GError **error)
 	pixels = gdk_pixbuf_get_pixels (pixbuf);
 	row_stride = gdk_pixbuf_get_rowstride (pixbuf);
 
-	if (context)
+	if (context && context->prepare_func)
 		(* context->prepare_func) (pixbuf, NULL, context->user_data);
 
 
@@ -338,7 +338,8 @@ gdk_pixbuf__xbm_image_load_real (FILE *f, XBMData *context, GError **error)
 	g_free (data);
 
 	if (context) {
-		(* context->update_func) (pixbuf, 0, 0, w, h, context->user_data);
+		if (context->update_func)
+			(* context->update_func) (pixbuf, 0, 0, w, h, context->user_data);
 		g_object_unref (pixbuf);
 		pixbuf = NULL;
 	}
@@ -434,10 +435,11 @@ gdk_pixbuf__xbm_image_load_increment (gpointer data,
 	g_return_val_if_fail (data != NULL, FALSE);
 
 	if (fwrite (buf, sizeof (guchar), size, context->file) != size) {
+		gint save_errno = errno;
 		context->all_okay = FALSE;
                 g_set_error (error,
                              G_FILE_ERROR,
-                             g_file_error_from_errno (errno),
+                             g_file_error_from_errno (save_errno),
                              _("Failed to write to temporary file when loading XBM image"));
 		return FALSE;
 	}
