@@ -536,10 +536,11 @@ make_list (const gchar  *text,
     }
 
   if (list)
-    *list = g_new (gchar *, n_strings + 1);
-
-  (*list)[n_strings] = NULL;
-  
+    {
+      *list = g_new (gchar *, n_strings + 1);
+      (*list)[n_strings] = NULL;
+    }
+     
   i = n_strings;
   tmp_list = strings;
   while (tmp_list)
@@ -548,10 +549,10 @@ make_list (const gchar  *text,
 	(*list)[--i] = tmp_list->data;
       else
 	g_free (tmp_list->data);
-
+      
       tmp_list = tmp_list->next;
     }
-
+  
   g_slist_free (strings);
 
   return n_strings;
@@ -591,7 +592,7 @@ gdk_text_property_to_utf8_list_for_display (GdkDisplay    *display,
     {
       return make_list ((gchar *)text, length, TRUE, list);
     }
-  else if (encoding == gdk_atom_intern ("UTF8_STRING", FALSE))
+  else if (encoding == gdk_atom_intern_static_string ("UTF8_STRING"))
     {
       return make_list ((gchar *)text, length, FALSE, list);
     }
