@@ -56,32 +56,36 @@
 #define GTK_PRINT_UNIX_DIALOG_GET_PRIVATE(o)  \
    (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTK_TYPE_PRINT_UNIX_DIALOG, GtkPrintUnixDialogPrivate))
 
-static void gtk_print_unix_dialog_destroy      (GtkPrintUnixDialog *dialog);
-static void gtk_print_unix_dialog_finalize     (GObject            *object);
-static void gtk_print_unix_dialog_set_property (GObject            *object,
-						guint               prop_id,
-						const GValue       *value,
-						GParamSpec         *pspec);
-static void gtk_print_unix_dialog_get_property (GObject            *object,
-						guint               prop_id,
-						GValue             *value,
-						GParamSpec         *pspec);
-static void gtk_print_unix_dialog_style_set    (GtkWidget          *widget,
-						GtkStyle           *previous_style);
-static void populate_dialog                    (GtkPrintUnixDialog *dialog);
-static void unschedule_idle_mark_conflicts     (GtkPrintUnixDialog *dialog);
-static void selected_printer_changed           (GtkTreeSelection   *selection,
-						GtkPrintUnixDialog *dialog);
-static void clear_per_printer_ui               (GtkPrintUnixDialog *dialog);
-static void printer_added_cb                   (GtkPrintBackend    *backend,
-						GtkPrinter         *printer,
-						GtkPrintUnixDialog *dialog);
-static void printer_removed_cb                 (GtkPrintBackend    *backend,
-						GtkPrinter         *printer,
-						GtkPrintUnixDialog *dialog);
-static void printer_status_cb                  (GtkPrintBackend    *backend,
-						GtkPrinter         *printer,
-						GtkPrintUnixDialog *dialog);
+static void     gtk_print_unix_dialog_destroy      (GtkPrintUnixDialog *dialog);
+static void     gtk_print_unix_dialog_finalize     (GObject            *object);
+static void     gtk_print_unix_dialog_set_property (GObject            *object,
+						    guint               prop_id,
+						    const GValue       *value,
+						    GParamSpec         *pspec);
+static void     gtk_print_unix_dialog_get_property (GObject            *object,
+						    guint               prop_id,
+						    GValue             *value,
+						    GParamSpec         *pspec);
+static void     gtk_print_unix_dialog_style_set    (GtkWidget          *widget,
+						    GtkStyle           *previous_style);
+static void     populate_dialog                    (GtkPrintUnixDialog *dialog);
+static void     unschedule_idle_mark_conflicts     (GtkPrintUnixDialog *dialog);
+static void     selected_printer_changed           (GtkTreeSelection   *selection,
+						    GtkPrintUnixDialog *dialog);
+static void     clear_per_printer_ui               (GtkPrintUnixDialog *dialog);
+static void     printer_added_cb                   (GtkPrintBackend    *backend,
+						    GtkPrinter         *printer,
+						    GtkPrintUnixDialog *dialog);
+static void     printer_removed_cb                 (GtkPrintBackend    *backend,
+						    GtkPrinter         *printer,
+						    GtkPrintUnixDialog *dialog);
+static void     printer_status_cb                  (GtkPrintBackend    *backend,
+						    GtkPrinter         *printer,
+						    GtkPrintUnixDialog *dialog);
+static void     update_collate_icon                (GtkToggleButton    *toggle_button,
+						    GtkPrintUnixDialog *dialog);
+static gboolean dialog_get_collate                 (GtkPrintUnixDialog *dialog);
+static gboolean dialog_get_reverse                 (GtkPrintUnixDialog *dialog);
 
 enum {
   PROP_0,
@@ -108,6 +112,9 @@ struct GtkPrintUnixDialogPrivate
   GtkWidget *notebook;
 
   GtkWidget *printer_treeview;
+
+  GtkPrintCapabilities manual_capabilities;
+  GtkPrintCapabilities printer_capabilities;
   
   GtkTreeModel *printer_list;
   GtkTreeModelFilter *printer_list_filter;
@@ -181,7 +188,7 @@ struct GtkPrintUnixDialogPrivate
   gint current_page;
 };
 
-G_DEFINE_TYPE (GtkPrintUnixDialog, gtk_print_unix_dialog, GTK_TYPE_DIALOG);
+G_DEFINE_TYPE (GtkPrintUnixDialog, gtk_print_unix_dialog, GTK_TYPE_DIALOG)
 
 static gboolean
 is_default_printer (GtkPrintUnixDialog *dialog,
@@ -241,10 +248,11 @@ gtk_print_unix_dialog_class_init (GtkPrintUnixDialogClass *class)
 				   PROP_SELECTED_PRINTER,
 				   g_param_spec_object ("selected-printer",
 							P_("Selected Printer"),
-							P_("The GtkPrinter which which is selected"),
+							P_("The GtkPrinter which is selected"),
 							GTK_TYPE_PRINTER,
 							GTK_PARAM_READABLE));
   
+  
   g_type_class_add_private (class, sizeof (GtkPrintUnixDialogPrivate));  
 }
 
@@ -262,20 +270,21 @@ gtk_print_unix_dialog_init (GtkPrintUnixDialog *dialog)
 
   priv->page_setup = gtk_page_setup_new ();
 
-  populate_dialog (dialog);
-
   g_signal_connect (dialog, 
                     "destroy", 
 		    (GCallback) gtk_print_unix_dialog_destroy, 
 		    NULL);
 
-  gtk_dialog_add_buttons (GTK_DIALOG (dialog), 
+  gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+			  GTK_STOCK_PRINT_PREVIEW, GTK_RESPONSE_APPLY, 
 			  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 			  GTK_STOCK_PRINT, GTK_RESPONSE_OK,
                           NULL);
 
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
   gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, FALSE);
+
+  populate_dialog (dialog);  
 }
 
 static void
@@ -1002,6 +1011,32 @@ update_dialog_from_settings (GtkPrintUnixDialog *dialog)
   g_list_free (groups);
 }
 
+static void
+update_dialog_from_capabilities (GtkPrintUnixDialog *dialog)
+{
+  GtkPrintCapabilities caps;
+  GtkPrintUnixDialogPrivate *priv = dialog->priv;
+  gboolean can_collate;
+
+  can_collate = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (priv->copies_spin)) > 1;
+
+  caps = priv->manual_capabilities | priv->printer_capabilities;
+
+  gtk_widget_set_sensitive (priv->page_set_combo,
+			    caps & GTK_PRINT_CAPABILITY_PAGE_SET);
+  gtk_widget_set_sensitive (priv->copies_spin,
+			    caps & GTK_PRINT_CAPABILITY_COPIES);
+  gtk_widget_set_sensitive (priv->collate_check,
+			    can_collate && 
+			    (caps & GTK_PRINT_CAPABILITY_COLLATE));
+  gtk_widget_set_sensitive (priv->reverse_check,
+			    caps & GTK_PRINT_CAPABILITY_REVERSE);
+  gtk_widget_set_sensitive (priv->scale_spin,
+			    caps & GTK_PRINT_CAPABILITY_PAGE_SET);
+
+  update_collate_icon (NULL, dialog);
+}
+
 static void
 mark_conflicts (GtkPrintUnixDialog *dialog)
 {
@@ -1214,11 +1249,14 @@ selected_printer_changed (GtkTreeSelection   *selection,
       g_object_unref (priv->current_printer);
     }
 
+  priv->printer_capabilities = 0;
+  
   gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, TRUE);
   priv->current_printer = printer;
 
   if (printer != NULL)
     {
+      priv->printer_capabilities = _gtk_printer_get_capabilities (printer);
       priv->options = _gtk_printer_get_options (printer, priv->initial_settings,
 							priv->page_setup);
   
@@ -1227,7 +1265,9 @@ selected_printer_changed (GtkTreeSelection   *selection,
     }
 
   update_dialog_from_settings (dialog);
+  update_dialog_from_capabilities (dialog);
 }
+
 static void
 update_collate_icon (GtkToggleButton    *toggle_button,
 		     GtkPrintUnixDialog *dialog)
@@ -1243,16 +1283,20 @@ paint_page (GtkWidget *widget,
 	    gfloat     scale,
 	    gint       x_offset, 
 	    gint       y_offset,
-	    gchar     *text)
+	    gchar     *text,
+	    gint       text_x)
 {
   gint x, y, width, height;
-  gint linewidth = 2;
+  gint text_y, linewidth;
 
   x = x_offset * scale;
   y = y_offset * scale;
   width = 20 * scale;
   height = 26 * scale;
 
+  linewidth = 2;
+  text_y = 21;
+
   gdk_cairo_set_source_color (cr, &widget->style->base[GTK_STATE_NORMAL]);
   cairo_rectangle (cr, x, y, width, height);
   cairo_fill (cr);
@@ -1266,7 +1310,7 @@ paint_page (GtkWidget *widget,
 			  CAIRO_FONT_SLANT_NORMAL,
 			  CAIRO_FONT_WEIGHT_NORMAL);
   cairo_set_font_size (cr, (gint)(9 * scale));
-  cairo_move_to (cr, x + (gint)(11 * scale), y + (gint)(21 * scale));
+  cairo_move_to (cr, x + (gint)(text_x * scale), y + (gint)(text_y * scale));
   cairo_show_text (cr, text);
 }
 
@@ -1276,15 +1320,16 @@ draw_collate_cb (GtkWidget	    *widget,
 		 GdkEventExpose     *event,
 		 GtkPrintUnixDialog *dialog)
 {
-  GtkPrintUnixDialogPrivate *priv = dialog->priv;
   GtkSettings *settings;
   cairo_t *cr;
   gint size;
   gfloat scale;
-  gboolean collate, reverse;
+  gboolean collate, reverse, rtl;
+  gint text_x;
 
-  collate = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->collate_check));
-  reverse = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->reverse_check));
+  collate = dialog_get_collate (dialog);
+  reverse = dialog_get_reverse (dialog);
+  rtl = (gtk_widget_get_direction (GTK_WIDGET (widget)) == GTK_TEXT_DIR_RTL);
 
   settings = gtk_widget_get_settings (widget);
   gtk_icon_size_lookup_for_settings (settings,
@@ -1292,14 +1337,15 @@ draw_collate_cb (GtkWidget	    *widget,
 				     &size,
 				     NULL);
   scale = size / 48.0;
+  text_x = rtl ? 4 : 11;
 
   cr = gdk_cairo_create (widget->window);
 
-  paint_page (widget, cr, scale, 15, 5, collate == reverse ? "1" : "2");
-  paint_page (widget, cr, scale, 5, 15, reverse ? "2" : "1");
+  paint_page (widget, cr, scale, rtl ? 40: 15, 5, collate == reverse ? "1" : "2", text_x);
+  paint_page (widget, cr, scale, rtl ? 50: 5, 15, reverse ? "2" : "1", text_x);
 
-  paint_page (widget, cr, scale, 50, 5, reverse ? "1" : "2");
-  paint_page (widget, cr, scale, 40, 15, collate == reverse ? "2" : "1");
+  paint_page (widget, cr, scale, rtl ? 5 : 50, 5, reverse ? "1" : "2", text_x);
+  paint_page (widget, cr, scale, rtl ? 15 : 40, 15, collate == reverse ? "2" : "1", text_x);
   
   cairo_destroy (cr);
 
@@ -1334,6 +1380,17 @@ gtk_print_unix_dialog_style_set (GtkWidget *widget,
     }
 }
 
+static void
+update_range_sensitivity (GtkWidget *button,
+			  GtkWidget *range)
+{
+  gboolean active;
+
+  active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+
+  gtk_widget_set_sensitive (range, active);
+}
+
 static void
 create_main_page (GtkPrintUnixDialog *dialog)
 {
@@ -1455,6 +1512,8 @@ create_main_page (GtkPrintUnixDialog *dialog)
   gtk_table_attach (GTK_TABLE (table), entry,
 		    1, 2, 2, 3,  GTK_FILL, 0,
 		    0, 0);
+  g_signal_connect (radio, "toggled", G_CALLBACK (update_range_sensitivity), entry);
+  update_range_sensitivity (radio, entry);
 
   table = gtk_table_new (3, 2, FALSE);
   gtk_table_set_row_spacings (GTK_TABLE (table), 6);
@@ -1463,7 +1522,7 @@ create_main_page (GtkPrintUnixDialog *dialog)
   gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
   gtk_widget_show (table);
 
-  /* FIXMEchpe: too much space between Copies and spinbutton, put those 2 in a hbox and make it span 2 columns */
+  /* FIXME chpe: too much space between Copies and spinbutton, put those 2 in a hbox and make it span 2 columns */
   label = gtk_label_new_with_mnemonic (_("Copie_s:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_widget_show (label);
@@ -1477,7 +1536,9 @@ create_main_page (GtkPrintUnixDialog *dialog)
 		    1, 2, 0, 1,  GTK_FILL, 0,
 		    0, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), spinbutton);
-
+  g_signal_connect_swapped (spinbutton, "value-changed", 
+			    G_CALLBACK (update_dialog_from_capabilities), dialog);
+  
   check = gtk_check_button_new_with_mnemonic (_("C_ollate"));
   priv->collate_check = check;
   g_signal_connect (check, "toggled", G_CALLBACK (update_collate_icon), dialog);
@@ -1485,6 +1546,7 @@ create_main_page (GtkPrintUnixDialog *dialog)
   gtk_table_attach (GTK_TABLE (table), check,
 		    0, 1, 1, 2,  GTK_FILL, 0,
 		    0, 0);
+
   check = gtk_check_button_new_with_mnemonic (_("_Reverse"));
   g_signal_connect (check, "toggled", G_CALLBACK (update_collate_icon), dialog);
   priv->reverse_check = check;
@@ -1500,7 +1562,7 @@ create_main_page (GtkPrintUnixDialog *dialog)
   gtk_table_attach (GTK_TABLE (table), image,
 		    1, 2, 1, 3, GTK_FILL, 0,
 		    0, 0);
-  g_signal_connect (image, "expose_event", G_CALLBACK (draw_collate_cb), dialog);
+  g_signal_connect (image, "expose-event", G_CALLBACK (draw_collate_cb), dialog);
 
   label = gtk_label_new (_("General"));
   gtk_widget_show (label);
@@ -1640,21 +1702,26 @@ dialog_set_print_pages (GtkPrintUnixDialog *dialog, GtkPrintPages pages)
 static gdouble
 dialog_get_scale (GtkPrintUnixDialog *dialog)
 {
-  return gtk_spin_button_get_value (GTK_SPIN_BUTTON (dialog->priv->scale_spin));
+  if (GTK_WIDGET_IS_SENSITIVE (dialog->priv->scale_spin))
+    return gtk_spin_button_get_value (GTK_SPIN_BUTTON (dialog->priv->scale_spin));
+  else
+    return 100.0;
 }
 
 static void
 dialog_set_scale (GtkPrintUnixDialog *dialog, 
                   gdouble             val)
 {
-  return gtk_spin_button_set_value (GTK_SPIN_BUTTON (dialog->priv->scale_spin),
-				    val);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (dialog->priv->scale_spin), val);
 }
 
 static GtkPageSet
 dialog_get_page_set (GtkPrintUnixDialog *dialog)
 {
-  return (GtkPageSet)gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->page_set_combo));
+  if (GTK_WIDGET_IS_SENSITIVE (dialog->priv->page_set_combo))
+    return (GtkPageSet)gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->page_set_combo));
+  else
+    return GTK_PAGE_SET_ALL;
 }
 
 static void
@@ -1668,7 +1735,9 @@ dialog_set_page_set (GtkPrintUnixDialog *dialog,
 static gint
 dialog_get_n_copies (GtkPrintUnixDialog *dialog)
 {
-  return gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (dialog->priv->copies_spin));
+  if (GTK_WIDGET_IS_SENSITIVE (dialog->priv->copies_spin))
+    return gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (dialog->priv->copies_spin));
+  return 1;
 }
 
 static void
@@ -1682,7 +1751,9 @@ dialog_set_n_copies (GtkPrintUnixDialog *dialog,
 static gboolean
 dialog_get_collate (GtkPrintUnixDialog *dialog)
 {
-  return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->collate_check));
+  if (GTK_WIDGET_IS_SENSITIVE (dialog->priv->collate_check))
+    return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->collate_check));
+  return FALSE;
 }
 
 static void
@@ -1696,7 +1767,9 @@ dialog_set_collate (GtkPrintUnixDialog *dialog,
 static gboolean
 dialog_get_reverse (GtkPrintUnixDialog *dialog)
 {
-  return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->reverse_check));
+  if (GTK_WIDGET_IS_SENSITIVE (dialog->priv->reverse_check))
+    return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->reverse_check));
+  return FALSE;
 }
 
 static void
@@ -1745,6 +1818,7 @@ draw_page_cb (GtkWidget	         *widget,
   PangoLayout *layout;
   PangoFontDescription *font;
   char *text;
+  GdkColor *color;
   
   orientation = gtk_page_setup_get_orientation (priv->page_setup);
   landscape =
@@ -1796,17 +1870,18 @@ draw_page_cb (GtkWidget	         *widget,
   
   shadow_offset = 3;
   
-  cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
+  color = &widget->style->text[GTK_STATE_NORMAL];
+  cairo_set_source_rgba (cr, color->red / 65535., color->green / 65535., color->blue / 65535, 0.5);
   cairo_rectangle (cr, shadow_offset + 1, shadow_offset + 1, w, h);
   cairo_fill (cr);
   
-  cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
+  gdk_cairo_set_source_color (cr, &widget->style->base[GTK_STATE_NORMAL]);
   cairo_rectangle (cr, 1, 1, w, h);
   cairo_fill (cr);
   cairo_set_line_width (cr, 1.0);
   cairo_rectangle (cr, 0.5, 0.5, w+1, h+1);
   
-  cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
+  gdk_cairo_set_source_color (cr, &widget->style->text[GTK_STATE_NORMAL]);
   cairo_stroke (cr);
 
   i = 1;
@@ -1912,7 +1987,7 @@ create_page_setup_page (GtkPrintUnixDialog *dialog)
 		    0, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
 
-  label = gtk_label_new_with_mnemonic (_("_Only Print:"));
+  label = gtk_label_new_with_mnemonic (_("_Only print:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_widget_show (label);
   gtk_table_attach (GTK_TABLE (table), label,
@@ -1963,7 +2038,7 @@ create_page_setup_page (GtkPrintUnixDialog *dialog)
   gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 6);
   gtk_widget_show (table);
 
-  label = gtk_label_new_with_mnemonic (_("Paper _Type:"));
+  label = gtk_label_new_with_mnemonic (_("Paper _type:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_widget_show (label);
   gtk_table_attach (GTK_TABLE (table), label,
@@ -1978,7 +2053,7 @@ create_page_setup_page (GtkPrintUnixDialog *dialog)
 		    0, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
 
-  label = gtk_label_new_with_mnemonic (_("Paper _Source:"));
+  label = gtk_label_new_with_mnemonic (_("Paper _source:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_widget_show (label);
   gtk_table_attach (GTK_TABLE (table), label,
@@ -1993,7 +2068,7 @@ create_page_setup_page (GtkPrintUnixDialog *dialog)
 		    0, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
 
-  label = gtk_label_new_with_mnemonic (_("Output T_ray:"));
+  label = gtk_label_new_with_mnemonic (_("Output t_ray:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_widget_show (label);
   gtk_table_attach (GTK_TABLE (table), label,
@@ -2016,7 +2091,7 @@ create_page_setup_page (GtkPrintUnixDialog *dialog)
   draw = gtk_drawing_area_new ();
   priv->page_layout_preview = draw;
   gtk_widget_set_size_request (draw, 200, 200);
-  g_signal_connect (draw, "expose_event", G_CALLBACK (draw_page_cb), dialog);
+  g_signal_connect (draw, "expose-event", G_CALLBACK (draw_page_cb), dialog);
   gtk_widget_show (draw);
 
   gtk_box_pack_start (GTK_BOX (hbox2), draw, TRUE, FALSE, 0);
@@ -2111,7 +2186,7 @@ create_job_page (GtkPrintUnixDialog *dialog)
 		    0, 0);
 
   radio = gtk_radio_button_new_with_mnemonic (gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio)),
-					      _("On _Hold"));
+					      _("On _hold"));
   priv->print_hold_radio = radio;
   gtk_widget_show (radio);
   gtk_table_attach (GTK_TABLE (table), radio,
@@ -2325,15 +2400,13 @@ gtk_print_unix_dialog_new (const gchar *title,
 
   if (title)
     _title = title;
-  
+
   result = g_object_new (GTK_TYPE_PRINT_UNIX_DIALOG,
+			 "transient-for", parent,
                          "title", _title,
 			 "has-separator", FALSE,
                          NULL);
-
-  if (parent)
-    gtk_window_set_transient_for (GTK_WINDOW (result), parent);
-
+  
   return result;
 }
 
@@ -2525,7 +2598,7 @@ gtk_print_unix_dialog_set_settings (GtkPrintUnixDialog *dialog,
     {
       dialog_set_collate (dialog, gtk_print_settings_get_collate (settings));
       dialog_set_reverse (dialog, gtk_print_settings_get_reverse (settings));
-      dialog_set_n_copies (dialog, gtk_print_settings_get_num_copies (settings));
+      dialog_set_n_copies (dialog, gtk_print_settings_get_n_copies (settings));
       dialog_set_scale (dialog, gtk_print_settings_get_scale (settings));
       dialog_set_page_set (dialog, gtk_print_settings_get_page_set (settings));
       dialog_set_print_pages (dialog, gtk_print_settings_get_print_pages (settings));
@@ -2601,8 +2674,8 @@ gtk_print_unix_dialog_get_settings (GtkPrintUnixDialog *dialog)
   gtk_print_settings_set_reverse (settings,
 				  dialog_get_reverse (dialog));
   
-  gtk_print_settings_set_num_copies (settings,
-				     dialog_get_n_copies (dialog));
+  gtk_print_settings_set_n_copies (settings,
+				   dialog_get_n_copies (dialog));
 
   gtk_print_settings_set_scale (settings,
 				dialog_get_scale (dialog));
@@ -2630,6 +2703,37 @@ gtk_print_unix_dialog_get_settings (GtkPrintUnixDialog *dialog)
   return settings;
 }
 
+void
+gtk_print_unix_dialog_add_custom_tab (GtkPrintUnixDialog *dialog,
+				      GtkWidget *child,
+				      GtkWidget *tab_label)
+{
+  gtk_notebook_insert_page (GTK_NOTEBOOK (dialog->priv->notebook),
+			    child, tab_label, 2);
+  gtk_widget_show (child);
+  gtk_widget_show (tab_label);
+}
+
+/**
+ * gtk_print_unix_dialog_set_manual_capabilities:
+ * @dialog: a #GtkPrintUnixDialog
+ * @capabilites: the printing capabilities of your application
+ *
+ * This lets you specify the printing capabilities your application
+ * supports. For instance, if you can handle scaling the output then
+ * you pass #GTK_PRINT_CAPABILITY_SCALE. If you don't pass that, then
+ * the dialog will only let you select the scale if the printing
+ * system automatically handles scaling.
+ *
+ * Since: 2.10
+ */
+void
+gtk_print_unix_dialog_set_manual_capabilities (GtkPrintUnixDialog *dialog,
+					       GtkPrintCapabilities capabilities)
+{
+  dialog->priv->manual_capabilities = capabilities;
+  update_dialog_from_capabilities (dialog);
+}
 
 #define __GTK_PRINT_UNIX_DIALOG_C__
 #include "gtkaliasdef.c"
